==> v0.7.0.zip: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/action/support/master/MasterNodeOperationRequest.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.support.master;

import org.elasticsearch.action.ActionRequest;
import org.elasticsearch.util.io.stream.StreamInput;
import org.elasticsearch.util.io.stream.StreamOutput;

import java.io.IOException;

/**
 * A based request for master based operation.
 *
 * @author kimchy (shay.banon)
 */
public abstract class MasterNodeOperationRequest implements ActionRequest {

    @Override public boolean listenerThreaded() {
        // always threaded
        return true;
    }

    @Override public MasterNodeOperationRequest listenerThreaded(boolean listenerThreaded) {
        // really, does not mean anything in this case
        return this;
    }

    @Override public void readFrom(StreamInput in) throws IOException {
    }

    @Override public void writeTo(StreamOutput out) throws IOException {
    }
}

==> v0.9.0.zip: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/action/support/master/MasterNodeOperationRequest.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.support.master;

import org.elasticsearch.action.ActionRequest;
import org.elasticsearch.common.io.stream.StreamInput;
import org.elasticsearch.common.io.stream.StreamOutput;
import org.elasticsearch.common.unit.TimeValue;

import java.io.IOException;

/**
 * A based request for master based operation.
 *
 * @author kimchy (shay.banon)
 */
public abstract class MasterNodeOperationRequest implements ActionRequest {

    private TimeValue masterNodeTimeout = TimeValue.timeValueSeconds(30);

    @Override public boolean listenerThreaded() {
        // always threaded
        return true;
    }

    @Override public MasterNodeOperationRequest listenerThreaded(boolean listenerThreaded) {
        // really, does not mean anything in this case
        return this;
    }

    /**
     * A timeout value in case the master has not been discovered yet or disconnected.
     */
    public MasterNodeOperationRequest masterNodeTimeout(TimeValue timeout) {
        this.masterNodeTimeout = timeout;
        return this;
    }

    public TimeValue masterNodeTimeout() {
        return this.masterNodeTimeout;
    }

    @Override public void readFrom(StreamInput in) throws IOException {
        masterNodeTimeout = TimeValue.readTimeValue(in);
    }

    @Override public void writeTo(StreamOutput out) throws IOException {
        masterNodeTimeout.writeTo(out);
    }
}
